
# Class: Relationship




URI: [ks:Relationship](https://w3id.org/linkml/tests/kitchen_sink/Relationship)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Relationship&#124;started_at_time:date%20%3F;ended_at_time:date%20%3F;related_to:string%20%3F;type:string%20%3F]^-[FamilialRelationship],[FamilialRelationship])](https://yuml.me/diagram/nofunky;dir:TB/class/[Relationship&#124;started_at_time:date%20%3F;ended_at_time:date%20%3F;related_to:string%20%3F;type:string%20%3F]^-[FamilialRelationship],[FamilialRelationship])

## Children

 * [FamilialRelationship](FamilialRelationship.md)

## Referenced by Class


## Attributes


### Own

 * [started at time](started_at_time.md)  <sub>0..1</sub>
     * Range: [Date](types/Date.md)
 * [ended at time](ended_at_time.md)  <sub>0..1</sub>
     * Range: [Date](types/Date.md)
 * [related to](related_to.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
 * [type](type.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
